# TileDB python pcl bindings

### package bringing some classes and functions from pcl into python

#### see https://github.com/davidcaron/pclpy (packaging issues and out-of-date)

#### WIP

#### get from pypi:
``
pip install tiledbpypcl
``
#### temp pypi account:
    - username: ctiledb
    - password: TileDBPCL

